@@ -104,7 +104,7 @@ class Neo4jPathFinder(Neo4jGraphProcessor, PathFinder):
             graph._generate_st_match_query(source, target) +
             Neo4jPathFinder._generate_path_search_call(
                 graph, source, target,
-                "gds.beta.shortestPath.yens.stream",
+                "gds.shortestPath.yens.stream",
                 distance, exclude_edge,
                 extra_params={"k": n}) +
             "YIELD nodeIds\n"
