@@ -162,12 +162,12 @@ def pgframe_to_neo4j(pgframe=None, uri=None, username=None, password=None,
         node_label_repr = f":{node_label}" if node_label else ""
 
         query = (
-        f"""
-        WITH [{", ".join(node_repr)}] AS batch
-        UNWIND batch as individual
-        CREATE (n{node_label_repr})
-        SET n += individual
-        """)
+            f"""
+            WITH [{", ".join(node_repr)}] AS batch
+            UNWIND batch as individual
+            CREATE (n{node_label_repr})
+            SET n += individual
+            """)
         execute(driver, query)
 
     # Add node types to the Neo4j node labels
@@ -189,6 +189,7 @@ def pgframe_to_neo4j(pgframe=None, uri=None, username=None, password=None,
         edge_labels = [edge_label]
 
     for edge_label in edge_labels:
+
         # Select edges of a given type, if applicable
         edges = pgframe.edges(
             raw_frame=True,
@@ -282,8 +283,9 @@ class Neo4jGraphProcessor(GraphProcessor):
     input PGFrames and read out PGFrames from the database.
     """
 
-    def __init__(self, pgframe=None, uri=None, username=None, password=None,
-                 driver=None, node_label=None, edge_label=None, directed=True):
+    def __init__(self, pgframe=None, directed=True,
+                 uri=None, username=None, password=None,
+                 driver=None, node_label=None, edge_label=None):
         if node_label is None:
             raise Neo4jGraphProcessor.ProcessorException(
                 "Cannot initialize a Neo4jMetricProcessor: "
