@@ -13,6 +13,7 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-from .data_structures import (ElementClassifier,
-                              EmbeddingPipeline)
+from .data_structures import ElementClassifier
+from .pipelines import EmbeddingPipeline
+
 from .utils import *
\ No newline at end of file
