@@ -17,6 +17,7 @@
 from bluegraph.backends.stellargraph import StellarGraphNodeEmbedder
 from bluegraph.backends.neo4j import (Neo4jNodeEmbedder, pgframe_to_neo4j,
                                       Neo4jGraphView)
+from bluegraph.backends.gensim import GensimNodeEmbedder
 
 
 def _execute(driver, query):
@@ -167,6 +168,16 @@ def test_stellar_node_embedder(node_embedding_test_graph,
         set(node_embedding_test_graph.nodes()) ==
         set(embedding.index))
 
+    embedder = StellarGraphNodeEmbedder(
+        "watchyourstep", epochs=100, num_walks=80,
+        num_powers=10, batch_size=4, embedding_dimension=64)
+    embedding = embedder.fit_model(
+        node_embedding_test_graph)
+    assert(len(embedding["embedding"].iloc[0]) == 64)
+    assert(
+        set(node_embedding_test_graph.nodes()) ==
+        set(embedding.index))
+
 
 def test_neo4j_node_embedder(node_embedding_test_graph,
                              node_embedding_prediction_test_graph,
@@ -257,3 +268,15 @@ def test_neo4j_node_embedder(node_embedding_test_graph,
     embedder.save("neo4j_sage_emedder", compress=True)
     embedder = Neo4jNodeEmbedder.load("neo4j_sage_emedder.zip")
     embedder.info()
+
+
+def test_gensim_node_embedder(node_embedding_test_graph,
+                              node_embedding_prediction_test_graph):
+    embedder = GensimNodeEmbedder(
+        "poincare", directed=True, size=6, epochs=100, negative=3)
+    embedding = embedder.fit_model(node_embedding_test_graph)
+    print(embedding)
+    assert(len(embedding["embedding"].iloc[0]) == 6)
+    assert(
+        set(node_embedding_test_graph.nodes()) ==
+        set(embedding.index))
